@@ -15,6 +15,7 @@ name = "python -m deepl"
 
 env_auth_key = "DEEPL_AUTH_KEY"
 env_server_url = "DEEPL_SERVER_URL"
+env_proxy_url = "DEEPL_PROXY_URL"
 
 
 def action_usage(translator: deepl.Translator):
@@ -23,19 +24,26 @@ def action_usage(translator: deepl.Translator):
     print(usage_result)
 
 
-def action_languages(translator: deepl.Translator):
+def action_languages(translator: deepl.Translator, glossary: bool):
     """Action function for the languages command."""
-    source_languages = translator.get_source_languages()
-    target_languages = translator.get_target_languages()
+    if glossary:
+        glossary_languages = translator.get_glossary_languages()
+        print("Language pairs supported for glossaries: (source, target)")
+        for language_pair in glossary_languages:
+            print(f"{language_pair.source_lang}, {language_pair.target_lang}")
+    else:
+        source_languages = translator.get_source_languages()
+        target_languages = translator.get_target_languages()
 
-    print("Source languages available:")
-    for language in source_languages:
-        print(f"{language.code}: {language.name}")
-    print("Target languages available:")
-    for language in target_languages:
-        print(
-            f"{language.code}: {language.name}{' (supports formality)' if language.supports_formality else ''}"
-        )
+        print("Source languages available:")
+        for language in source_languages:
+            print(f"{language.code}: {language.name}")
+        print("Target languages available:")
+        for language in target_languages:
+            if language.supports_formality:
+                print(f"{language.code}: {language.name} (supports formality)")
+            else:
+                print(f"{language.code}: {language.name}")
 
 
 def action_document(
@@ -194,6 +202,13 @@ def get_parser(prog_name):
         help=f"alternative server URL for testing; the {env_server_url} "
         f"environment variable may be used as secondary fallback",
     )
+    parser.add_argument(
+        "--proxy-url",
+        default=None,
+        metavar="URL",
+        help=f"proxy server URL to use for all connections; the {env_proxy_url} "
+        f"environment variable may be used as secondary fallback",
+    )
 
     # Note: add_subparsers param 'required' is not available in py36
     subparsers = parser.add_subparsers(metavar="command", dest="command")
@@ -327,9 +342,14 @@ def get_parser(prog_name):
 
     # create the parser for the "languages" command
     languages_help_str = "print available languages"
-    subparsers.add_parser(
+    parser_languages = subparsers.add_parser(
         "languages", help=languages_help_str, description=languages_help_str
     )
+    parser_languages.add_argument(
+        "--glossary",
+        help="list language pairs supported for glossaries.",
+        action="store_true",
+    )
 
     # create the parser for the "glossary" command
     parser_glossary = subparsers.add_parser(
@@ -455,6 +475,7 @@ def main(args=None, prog_name=None):
 
     server_url = args.server_url or os.getenv(env_server_url)
     auth_key = args.auth_key or os.getenv(env_auth_key)
+    proxy_url = args.proxy_url or os.getenv(env_proxy_url)
 
     try:
         if auth_key is None:
@@ -466,7 +487,10 @@ def main(args=None, prog_name=None):
         # Note: the get_languages() call to verify language codes is skipped
         #       because the CLI makes one API call per execution.
         translator = deepl.Translator(
-            auth_key=auth_key, server_url=server_url, skip_language_check=True
+            auth_key=auth_key,
+            server_url=server_url,
+            proxy=proxy_url,
+            skip_language_check=True,
         )
 
         if args.command == "text":
@@ -481,7 +505,7 @@ def main(args=None, prog_name=None):
                 sys.exit(1)
 
         # Remove global args so they are not unrecognised in action functions
-        del args.verbose, args.server_url, args.auth_key
+        del args.verbose, args.server_url, args.auth_key, args.proxy_url
         args = vars(args)
         # Call action function corresponding to command with remaining args
         command = args.pop("command")
